﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/frauddetector/FraudDetector_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/frauddetector/model/ModelScores.h>
#include <aws/frauddetector/model/RuleResult.h>
#include <utility>

namespace Aws
{
template<typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils
{
namespace Json
{
  class JsonValue;
} // namespace Json
} // namespace Utils
namespace FraudDetector
{
namespace Model
{
  class AWS_FRAUDDETECTOR_API GetPredictionResult
  {
  public:
    GetPredictionResult();
    GetPredictionResult(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
    GetPredictionResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);


    /**
     * <p>The prediction outcomes.</p>
     */
    inline const Aws::Vector<Aws::String>& GetOutcomes() const{ return m_outcomes; }

    /**
     * <p>The prediction outcomes.</p>
     */
    inline void SetOutcomes(const Aws::Vector<Aws::String>& value) { m_outcomes = value; }

    /**
     * <p>The prediction outcomes.</p>
     */
    inline void SetOutcomes(Aws::Vector<Aws::String>&& value) { m_outcomes = std::move(value); }

    /**
     * <p>The prediction outcomes.</p>
     */
    inline GetPredictionResult& WithOutcomes(const Aws::Vector<Aws::String>& value) { SetOutcomes(value); return *this;}

    /**
     * <p>The prediction outcomes.</p>
     */
    inline GetPredictionResult& WithOutcomes(Aws::Vector<Aws::String>&& value) { SetOutcomes(std::move(value)); return *this;}

    /**
     * <p>The prediction outcomes.</p>
     */
    inline GetPredictionResult& AddOutcomes(const Aws::String& value) { m_outcomes.push_back(value); return *this; }

    /**
     * <p>The prediction outcomes.</p>
     */
    inline GetPredictionResult& AddOutcomes(Aws::String&& value) { m_outcomes.push_back(std::move(value)); return *this; }

    /**
     * <p>The prediction outcomes.</p>
     */
    inline GetPredictionResult& AddOutcomes(const char* value) { m_outcomes.push_back(value); return *this; }


    /**
     * <p>The model scores for models used in the detector version.</p>
     */
    inline const Aws::Vector<ModelScores>& GetModelScores() const{ return m_modelScores; }

    /**
     * <p>The model scores for models used in the detector version.</p>
     */
    inline void SetModelScores(const Aws::Vector<ModelScores>& value) { m_modelScores = value; }

    /**
     * <p>The model scores for models used in the detector version.</p>
     */
    inline void SetModelScores(Aws::Vector<ModelScores>&& value) { m_modelScores = std::move(value); }

    /**
     * <p>The model scores for models used in the detector version.</p>
     */
    inline GetPredictionResult& WithModelScores(const Aws::Vector<ModelScores>& value) { SetModelScores(value); return *this;}

    /**
     * <p>The model scores for models used in the detector version.</p>
     */
    inline GetPredictionResult& WithModelScores(Aws::Vector<ModelScores>&& value) { SetModelScores(std::move(value)); return *this;}

    /**
     * <p>The model scores for models used in the detector version.</p>
     */
    inline GetPredictionResult& AddModelScores(const ModelScores& value) { m_modelScores.push_back(value); return *this; }

    /**
     * <p>The model scores for models used in the detector version.</p>
     */
    inline GetPredictionResult& AddModelScores(ModelScores&& value) { m_modelScores.push_back(std::move(value)); return *this; }


    /**
     * <p>The rule results in the prediction.</p>
     */
    inline const Aws::Vector<RuleResult>& GetRuleResults() const{ return m_ruleResults; }

    /**
     * <p>The rule results in the prediction.</p>
     */
    inline void SetRuleResults(const Aws::Vector<RuleResult>& value) { m_ruleResults = value; }

    /**
     * <p>The rule results in the prediction.</p>
     */
    inline void SetRuleResults(Aws::Vector<RuleResult>&& value) { m_ruleResults = std::move(value); }

    /**
     * <p>The rule results in the prediction.</p>
     */
    inline GetPredictionResult& WithRuleResults(const Aws::Vector<RuleResult>& value) { SetRuleResults(value); return *this;}

    /**
     * <p>The rule results in the prediction.</p>
     */
    inline GetPredictionResult& WithRuleResults(Aws::Vector<RuleResult>&& value) { SetRuleResults(std::move(value)); return *this;}

    /**
     * <p>The rule results in the prediction.</p>
     */
    inline GetPredictionResult& AddRuleResults(const RuleResult& value) { m_ruleResults.push_back(value); return *this; }

    /**
     * <p>The rule results in the prediction.</p>
     */
    inline GetPredictionResult& AddRuleResults(RuleResult&& value) { m_ruleResults.push_back(std::move(value)); return *this; }

  private:

    Aws::Vector<Aws::String> m_outcomes;

    Aws::Vector<ModelScores> m_modelScores;

    Aws::Vector<RuleResult> m_ruleResults;
  };

} // namespace Model
} // namespace FraudDetector
} // namespace Aws
